/**
 * Copyright 2017 SmartBear Software
 * <p>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * <p>
 * http://www.apache.org/licenses/LICENSE-2.0
 * <p>
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.eclipse.microprofile.openapi.annotations.responses;

import java.lang.annotation.ElementType;
import java.lang.annotation.Inherited;
import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;
import java.lang.annotation.Target;

import org.eclipse.microprofile.openapi.annotations.extensions.Extension;

/**
 * The ApiResponses annotation is a container for @ApiResponse annotations. When used on a method it is treated as if
 * each ApiResponse annotation were applied individually.
 *
 * @see <a href="https://spec.openapis.org/oas/v3.1.0.html#responses-object">OpenAPI Specification Responses Object</a>
 **/
@Target({ElementType.METHOD, ElementType.TYPE})
@Retention(RetentionPolicy.RUNTIME)
@Inherited
public @interface APIResponses {
    /**
     * An array of APIResponse annotations
     *
     * @return the array of the APIResponse
     **/
    APIResponse[] value() default {};

    /**
     * List of extensions to be added to the {@link org.eclipse.microprofile.openapi.models.responses.APIResponses
     * APIResponses} model corresponding to the containing annotation.
     *
     * @return array of extensions
     *
     * @since 3.1
     */
    Extension[] extensions() default {};
}
